@@ -272,6 +272,16 @@
  */
 #define PANGO_VERSION_1_48       (G_ENCODE_VERSION (1, 48))
 
+/**
+ * PANGO_VERSION_1_50:
+ *
+ * A macro that evaluates to the 1.50 version of Pango, in a format
+ * that can be used by the C pre-processor.
+ *
+ * Since: 1.50
+ */
+#define PANGO_VERSION_1_50       (G_ENCODE_VERSION (1, 50))
+
 /* evaluates to the current stable version; for development cycles,
  * this means the next stable target
  */
@@ -705,4 +715,18 @@
 # define PANGO_AVAILABLE_IN_1_48                _PANGO_EXTERN
 #endif
 
+#if PANGO_VERSION_MIN_REQUIRED >= PANGO_VERSION_1_50
+# define PANGO_DEPRECATED_IN_1_50               PANGO_DEPRECATED
+# define PANGO_DEPRECATED_IN_1_50_FOR(f)        PANGO_DEPRECATED_FOR(f)
+#else
+# define PANGO_DEPRECATED_IN_1_50               _PANGO_EXTERN
+# define PANGO_DEPRECATED_IN_1_50_FOR(f)        _PANGO_EXTERN
+#endif
+
+#if PANGO_VERSION_MAX_ALLOWED < PANGO_VERSION_1_50
+# define PANGO_AVAILABLE_IN_1_50                PANGO_UNAVAILABLE(1, 50)
+#else
+# define PANGO_AVAILABLE_IN_1_50                _PANGO_EXTERN
+#endif
+
 #endif /* __PANGO_VERSION_H__ */
